==> hu35ksubc_1.10.0.tar.gz: hu35ksubc/man/hu35ksubcREFSEQ.Rd <==
\name{hu35ksubcREFSEQ}
\alias{hu35ksubcREFSEQ}
\title{Map between Manufacturer Identifiers and RefSeq Identifiers}
\description{
   hu35ksubcREFSEQ is an R environment that provides mappings between
   manufacturer ids and RefSeq ids.
}
\details{
  Each manufacturer id is mapped to a named vector of RefSeq ids. The
  name represents the manufacturer id and the vector contains all RefSeq
  ids that can be mapped to that manufacturer id. The length of the
  vector may be one or greater, depending on how many RefSeq ids a given
  manufacturer id can be mapped to. An \code{NA} is reported for any
  manufacturer id that cannot be mapped to a RefSeq id at this time.

  RefSeq ids differ in format according to the type of record the ids
  are for as shown below:

  NG\_XXXXX: RefSeq accessions for genomic region (nucleotide) records

  NM\_XXXXX: RefSeq accessions for mRNA records

  NC\_XXXXX: RefSeq accessions for chromosome records

  NP\_XXXXX: RefSeq accessions for protein records

  XR\_XXXXX: RefSeq accessions for model RNAs that are not associated with
  protein products

  XM\_XXXXX: RefSeq accessions for model mRNA records

  XP\_XXXXX: RefSeq accessions for model protein records

  Where XXXXX is a sequence of integers.

  NCBI \url{http://www.ncbi.nlm.nih.gov/RefSeq/} allows users to query
  the RefSeq database using RefSeq ids.

  Mappings were based on data provided by:

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Wed Oct 12 14:17:23 2005

  Package built Wed Oct 12 14:30:40 2005
}
\references{
    \url{http://www.ncbi.nlm.nih.gov}
    \url{http://www.ncbi.nlm.nih.gov/RefSeq/} 
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hu35ksubcREFSEQ)
    # Remove probe ids that do not map to any RefSeq
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
    # The RefSeq for the first two elements of XX
    xx[1:2]
    # Get the first one
    xx[[1]]
}
}

\keyword{datasets}

==> hu35ksubc_1.12.0.tar.gz: hu35ksubc/man/hu35ksubcREFSEQ.Rd <==
\name{hu35ksubcREFSEQ}
\alias{hu35ksubcREFSEQ}
\title{Map between Manufacturer Identifiers and RefSeq Identifiers}
\description{
   hu35ksubcREFSEQ is an R environment that provides mappings between
   manufacturer ids and RefSeq ids.
}
\details{
  Each manufacturer id is mapped to a named vector of RefSeq ids. The
  name represents the manufacturer id and the vector contains all RefSeq
  ids that can be mapped to that manufacturer id. The length of the
  vector may be one or greater, depending on how many RefSeq ids a given
  manufacturer id can be mapped to. An \code{NA} is reported for any
  manufacturer id that cannot be mapped to a RefSeq id at this time.

  RefSeq ids differ in format according to the type of record the ids
  are for as shown below:

  NG\_XXXXX: RefSeq accessions for genomic region (nucleotide) records

  NM\_XXXXX: RefSeq accessions for mRNA records

  NC\_XXXXX: RefSeq accessions for chromosome records

  NP\_XXXXX: RefSeq accessions for protein records

  XR\_XXXXX: RefSeq accessions for model RNAs that are not associated with
  protein products

  XM\_XXXXX: RefSeq accessions for model mRNA records

  XP\_XXXXX: RefSeq accessions for model protein records

  Where XXXXX is a sequence of integers.

  NCBI \url{http://www.ncbi.nlm.nih.gov/RefSeq/} allows users to query
  the RefSeq database using RefSeq ids.

  Mappings were based on data provided by:

  Entrez Gene:\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Sun Mar 26 03:41:51 2006

  Package built Sun Mar 26 03:56:42 2006
}
\references{
    \url{http://www.ncbi.nlm.nih.gov}
    \url{http://www.ncbi.nlm.nih.gov/RefSeq/} 
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hu35ksubcREFSEQ)
    # Remove probe ids that do not map to any RefSeq
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
    # The RefSeq for the first two elements of XX
    xx[1:2]
    # Get the first one
    xx[[1]]
}
}

\keyword{datasets}
